#FIGURES OF CLUBROOT TRIAL MODELS FOR BRITTANY HENNIG
#WRITTEN BY SAMUEL ROBINSON, SPRING 2020

# Load everything ---------------------------------------------------------
library(tidyverse) #Loads ggplot2, dplyr, tidyr, and other packages
library(nlme)

theme_set(theme_classic()) #Sets the ggplot2 theme to "classic"

setwd("~/Projects/Stats projects/2020/Brittany Hennig") #Change working directory

#Logit/invLogit functions
logit <- function(x) log(x/(1-x))
invLogit <- function(x) exp(x)/(1+exp(x))

dat <- read.csv('clubrootData.csv') %>% #Read csv file
  mutate(propSus=ifelse(totalweeds==0,0,Sweeds/totalweeds)) %>% 
  mutate(across(c(fieldyear,tr,Genetics,Lime,Weeds,block),factor)) %>% 
  mutate(rating=ifelse(rating==0,0.01,ifelse(rating==1,0.99,rating))) %>% #Restricts between 0 and 1 for logit
  mutate(logitRating=logit(rating),logGw=log(gw+1)) #Transformations
dat_no2018 <- dat %>% filter(fieldyear!='2018') #Separate dataframe without 2018 values

summary(dat)

# Columns:
#fieldyear = field + year combination
#tr = treatment (combination of Genetics, Lime, Weeds)
#Genetics = resistant/susceptible
#Lime = lime/no lime
#Weeds = weeds/no weeds
#block = treatment block
#totalweeds = count of weeds in plot
#Sweeds = count of susceptible weeds in plot
#sw = shoot weight
#rw = root weight
#gw = gall weight
#rating = disease rating
#height = shoot height
#yield = mass of seeds
#qPCR = PCR counts
#propSus = proportion of susceptible weeds
#logitRating = logit-transformed disease rating
#logGw = log+1 transformed gall weight

#Function to look at residual plots for lme objects
resPlotLme <- function(mod){
  nranef <- length(ranef(mod)) #Number of random effects
  
  par(mfrow=c(1+nranef %/% 2 ,2))
  r <- resid(mod)
  plot(fitted(mod),r,xlab='Fitted',ylab='Residual'); abline(h=0)
  qqnorm(r,main='Residual'); qqline(r) #qqplots
  for(i in 1: nranef){
    re <- ranef(mod)[[i]][,1]
    rename <- names(ranef(mod)[i])
    qqnorm(re,main=rename); qqline(re) #qqplots
  }
  par(mfrow=c(1,1))
}

getVarComp <- function(x){ #Get variance components from lme object
  a <- nlme::VarCorr(x)
  SD <- as.numeric(a[,2])
  na <- rownames(a)
  na[which(na=="(Intercept)")] <- na[which(na=="(Intercept)") - 1]
  na <- gsub(' =','',na)
  ret <- data.frame(name=na,SD)
  ret[complete.cases(ret),]
}

# Weed measurements -------------------------------------------------------

panel.cor <- function(x, y, digits = 2, prefix = "", cex.cor, ...) #Function to get correlations between columns
{
  usr <- par("usr"); on.exit(par(usr))
  par(usr = c(0, 1, 0, 1))
  r <- abs(cor(x, y))
  txt <- format(c(r, 0.123456789), digits = digits)[1]
  txt <- paste0(prefix, txt)
  if(missing(cex.cor)) cex.cor <- 0.8/strwidth(txt)
  text(0.5, 0.5, txt, cex = cex.cor * r)
}

#High correlation between Weeds, totalweeds, Sweeds, propSus (I turned all NA values into zeros). These models are all going to tell you similar things: 
pairs(dat_no2018[,c('Weeds','totalweeds','Sweeds','propSus')],upper.panel=panel.cor)

#Get boostrapped p-values for totalweeds:propsus correlation
rSim <- replicate(10000,expr={
  rfun <- function(x) cor(x$totalweeds,x$propSus)
  rfun(dat_no2018[sample(x = 1:nrow(dat_no2018),size = nrow(dat_no2018),replace = TRUE),])
})
hist(rSim); abline(v=cor(dat_no2018$totalweeds,dat_no2018$propSus),col='red')



# Fit models ---------------------------------------------------------------

#Model of spore counts, using only 2019 data
sporeMod <- lme(log(qPCR) ~ Genetics*Lime*Weeds, 
                random=~1|fieldyear/block, 
                data=dat_no2018) #Only 2019 data

summary(sporeMod) #Strong effect of Genetics, but marginal Genetics:Lime, Lime:Weeds, and Genetics:Lime:Weeds interactions
resPlotLme(sporeMod) #Residuals look OK. Not great for block, but not the end of the world

#Model of yield, using all years data
yieldMod <- lme(yield ~ Genetics*Lime*Weeds, 
                 random=~1|fieldyear/block, data=dat)

resPlotLme(yieldMod) #Looks OK
summary(yieldMod) #Strong effect of Genetics, Weeds, Genetics:Lime, and weak effect of Genetics:Weeds

#Disease rating model
diseaseMod <- lme(logitRating ~ Genetics*Lime*Weeds, 
                  random=~1|fieldyear/block, data=dat)
resPlotLme(diseaseMod) #Looks OK
summary(diseaseMod)

# Shoot weight model
swMod <- lme(sw ~ Genetics*Lime*Weeds,
             random=~1|fieldyear/block, data=dat)
resPlotLme(swMod)

# Gall weight model
gwMod <- lme(logGw ~ Genetics*Lime*Weeds,
             random=~1|fieldyear/block, data=dat)
resPlotLme(gwMod)

# Shoot height model
heightMod <- lme(height ~ Genetics*Lime*Weeds,
                 random=~1|fieldyear/block, data=dat)
resPlotLme(heightMod)

#Get ANOVA tables for each model, and collect into a single csv
modList <- list(sporeMod,yieldMod,diseaseMod,swMod,gwMod,heightMod) %>% 
  lapply(.,function(x){
  anova(x,type='sequential') %>% rownames_to_column('Term') %>% 
    data.frame() %>% unite('DF',contains('DF'),sep=',')}) %>% 
  set_names(c('spores','yield','disease','shootWeight','gallWeight','height')) %>% 
  bind_rows(.id='model') %>% 
  filter(!grepl('Intercept',Term))

write.csv(modList,'clubrootAnovaModels.csv')

#Get variance components for each model, collect into a single csv
modList <- list(sporeMod,yieldMod,diseaseMod,swMod,gwMod,heightMod) %>% 
  lapply(.,getVarComp) %>% 
  set_names(c('spores','yield','disease','shootWeight','gallWeight','height')) %>% 
  bind_rows(.id='model')

write.csv(modList,'clubrootVarComp.csv')

# Make plots ------------------------------------------------------------

# Goal: make partial effects plots of Genetics, Lime treatments, marginalizing over ("adjusting") other fixed and random effects

library(ggeffects)
library(ggpubr)
library(emmeans)
library(multcomp)

#Predictions for spore model
sporePred <- ggpredict(sporeMod,terms=c('Genetics','Lime','Weeds')) %>% as.data.frame() %>% 
  mutate(x=ifelse(x=='R','Resistant','Susceptible'),group=ifelse(group=='L','Lime','No Lime'),
         facet=ifelse(facet=='NW','No Weeds','Weeds')) %>% 
  mutate(label=paste0(facet,'\n',group)) %>% 
  mutate(across(c(predicted,conf.high,conf.low),~.x/1e6)) #Turns predictions into 100000s of counts

#Get CLD from multcomp test
sporePred$letter <- cld(emmeans(sporeMod,~Genetics+Lime+Weeds),alpha=0.05,Letters=letters) %>% 
  arrange(Genetics,Lime,Weeds) %>% pull(.group) %>% gsub(' ','',.)

(p1 <- ggplot(sporePred,aes(x=label,y=predicted,shape=x,linetype=x))+
  geom_pointrange(aes(ymax=conf.high,ymin=conf.low),position=position_dodge(width=0.2))+
  geom_text(aes(label=letter),position=position_dodge(width=1))+
  labs(x=NULL,y='Spores per g soil (x100,000)',linetype=NULL,shape=NULL)+
  scale_y_log10()+ #y-axis in log-units
  theme(axis.text.x=element_blank())
  )

#Predictions for yield model
yieldPred <- ggpredict(yieldMod,terms=c('Genetics','Lime','Weeds')) %>% 
  as.data.frame() %>% 
  mutate(x=ifelse(x=='R','Resistant','Susceptible'),group=ifelse(group=='L','Lime','No Lime'),
         facet=ifelse(facet=='NW','No Weeds','Weeds')) %>% 
  mutate(label=paste0(facet,'\n',group)) %>% 
  mutate(across(c(predicted,conf.low,conf.high),~.x/1000)) #Convert to kg

#Get CLD from multcomp test
yieldPred$letter <- cld(emmeans(yieldMod,~Genetics+Lime+Weeds),alpha=0.05,Letters=letters) %>% 
  arrange(Genetics,Lime,Weeds) %>% pull(.group) %>% gsub(' ','',.)

(p2 <- ggplot(yieldPred,aes(x=label,y=predicted,shape=x,linetype=x))+
    geom_pointrange(aes(ymax=conf.high,ymin=conf.low),position=position_dodge(width=0.2))+
    geom_text(aes(label=letter),position=position_dodge(width=1))+
    labs(x=NULL,y='Yield per plot (kg)',linetype=NULL,shape=NULL)+
    theme(axis.text.x=element_blank()))

#Predictions for disease model
diseasePred <- ggpredict(diseaseMod,terms=c('Genetics','Lime','Weeds')) %>% 
  as.data.frame() %>% 
  mutate(x=ifelse(x=='R','Resistant','Susceptible'),group=ifelse(group=='L','Lime','No Lime'),
         facet=ifelse(facet=='NW','No Weeds','Weeds')) %>% 
  mutate(label=paste0(facet,'\n',group)) %>% 
  mutate(across(c(predicted,contains('conf.')),~100*invLogit(.x))) #Back-transform

diseasePred$letter <- cld(emmeans(diseaseMod,~Genetics+Lime+Weeds),alpha=0.05,Letters=letters) %>% 
  arrange(Genetics,Lime,Weeds) %>% pull(.group) %>% gsub(' ','',.)

(p3 <- ggplot(diseasePred,aes(x=label,y=predicted,shape=x,linetype=x))+
    geom_pointrange(aes(ymax=conf.high,ymin=conf.low),position=position_dodge(width=0.2))+
    geom_text(aes(label=letter),position=position_dodge(width=1))+
    labs(x=NULL,y='Index of Disease (%)',linetype=NULL,shape=NULL)+
    theme(axis.text.x=element_text(angle=90,vjust=0.5)))

#Predictions for shoot weight model
swPred <- ggpredict(swMod,terms=c('Genetics','Lime','Weeds')) %>% 
  as.data.frame() %>% 
  mutate(x=ifelse(x=='R','Resistant','Susceptible'),group=ifelse(group=='L','Lime','No Lime'),
         facet=ifelse(facet=='NW','No Weeds','Weeds')) %>% 
  mutate(label=paste0(facet,'\n',group)) %>% 
  mutate(across(c(predicted,conf.low,conf.high),~.x/1000)) #Convert to kg

swPred$letter <- cld(emmeans(swMod,~Genetics+Lime+Weeds),alpha=0.05,Letters=letters) %>% 
  arrange(Genetics,Lime,Weeds) %>% pull(.group) %>% gsub(' ','',.)

(p4 <- ggplot(swPred,aes(x=label,y=predicted,shape=x,linetype=x))+
    geom_pointrange(aes(ymax=conf.high,ymin=conf.low),position=position_dodge(width=0.2))+
    geom_text(aes(label=letter),position=position_dodge(width=1))+
    labs(x=NULL,y='Shoot Weight of 10 Plants (kg)',linetype=NULL,shape=NULL)+
    theme(axis.text.x=element_blank()))

#Predictions for gall weight model
gwPred <- ggpredict(gwMod,terms=c('Genetics','Lime','Weeds')) %>% 
  as.data.frame() %>% 
  mutate(x=ifelse(x=='R','Resistant','Susceptible'),group=ifelse(group=='L','Lime','No Lime'),
         facet=ifelse(facet=='NW','No Weeds','Weeds')) %>% 
  mutate(label=paste0(facet,'\n',group)) %>%
  mutate(across(c(predicted,conf.low,conf.high),~exp(.x)-1)) #Backtransform

gwPred$letter <- cld(emmeans(gwMod,~Genetics+Lime+Weeds),alpha=0.05,Letters=letters) %>% 
  arrange(Genetics,Lime,Weeds) %>% pull(.group) %>% gsub(' ','',.)

(p5 <- ggplot(gwPred,aes(x=label,y=predicted,shape=x,linetype=x))+
    geom_pointrange(aes(ymax=conf.high,ymin=conf.low),position=position_dodge(width=0.2))+
    geom_text(aes(label=letter),position=position_dodge(width=1))+
    labs(x=NULL,y='Gall Weight of 10 Plants (g)',linetype=NULL,shape=NULL)+
    theme(axis.text.x=element_blank()))

#Predictions for shoot height model
heightPred <- ggpredict(heightMod,terms=c('Genetics','Lime','Weeds')) %>% 
  as.data.frame() %>% 
  mutate(x=ifelse(x=='R','Resistant','Susceptible'),group=ifelse(group=='L','Lime','No Lime'),
         facet=ifelse(facet=='NW','No Weeds','Weeds')) %>% 
  mutate(label=paste0(facet,'\n',group)) 

heightPred$letter <- cld(emmeans(heightMod,~Genetics+Lime+Weeds),alpha=0.05,Letters=letters) %>% 
  arrange(Genetics,Lime,Weeds) %>% pull(.group) %>% gsub(' ','',.)

(p6 <- ggplot(heightPred,aes(x=label,y=predicted,shape=x,linetype=x))+
    geom_pointrange(aes(ymax=conf.high,ymin=conf.low),position=position_dodge(width=0.2))+
    geom_text(aes(label=letter),position=position_dodge(width=1))+
    labs(x=NULL,y='Shoot Height (cm)',linetype=NULL,shape=NULL)+
    theme(axis.text.x=element_text(angle=90,vjust=0.5)))


#Put plots together 

#First three models
(p <- ggarrange(p1,p2,p3,ncol=1,heights=c(1,1,1.2),align = 'v',legend = 'bottom',common.legend = TRUE,labels='AUTO'))
ggsave('resultPlot.png',p,height=10,width=5,bg = 'white')

#All models
(p <- ggarrange(p1,p4,p2,
                p5,p3,p6,
                ncol=2,nrow=3,heights=c(1,1,1.2,1,1,1.2),
                align = 'v',legend = 'bottom',common.legend = TRUE,labels=c('A','D','B','E','C','F')))
ggsave('resultPlot2.png',p,height=10,width=10,bg = 'white')

#Done
